package muicm.diagram.part;

import org.eclipse.core.runtime.Platform;
import org.eclipse.emf.ecore.EAnnotation;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.gmf.runtime.notation.Diagram;
import org.eclipse.gmf.runtime.notation.View;
import org.eclipse.gmf.tooling.runtime.structure.DiagramStructure;

import muicm.MuicmPackage;
import muicm.diagram.edit.parts.*;

/**
 * This registry is used to determine which type of visual object should be
 * created for the corresponding Diagram, Node, ChildNode or Link represented
 * by a domain model object.
 * 
 * @generated
 */
public class MuicmVisualIDRegistry {

	/**
	* @generated
	*/
	private static final String DEBUG_KEY = "muicm.diagram/debug/visualID"; //$NON-NLS-1$

	/**
	* @generated
	*/
	public static int getVisualID(View view) {
		if (view instanceof Diagram) {
			if (MUICMEditPart.MODEL_ID.equals(view.getType())) {
				return MUICMEditPart.VISUAL_ID;
			} else {
				return -1;
			}
		}
		return muicm.diagram.part.MuicmVisualIDRegistry.getVisualID(view.getType());
	}

	/**
	* @generated
	*/
	public static String getModelID(View view) {
		View diagram = view.getDiagram();
		while (view != diagram) {
			EAnnotation annotation = view.getEAnnotation("Shortcut"); //$NON-NLS-1$
			if (annotation != null) {
				return (String) annotation.getDetails().get("modelID"); //$NON-NLS-1$
			}
			view = (View) view.eContainer();
		}
		return diagram != null ? diagram.getType() : null;
	}

	/**
	* @generated
	*/
	public static int getVisualID(String type) {
		try {
			return Integer.parseInt(type);
		} catch (NumberFormatException e) {
			if (Boolean.TRUE.toString().equalsIgnoreCase(Platform.getDebugOption(DEBUG_KEY))) {
				MuicmDiagramEditorPlugin.getInstance()
						.logError("Unable to parse view type as a visualID number: " + type);
			}
		}
		return -1;
	}

	/**
	* @generated
	*/
	public static String getType(int visualID) {
		return Integer.toString(visualID);
	}

	/**
	* @generated
	*/
	public static int getDiagramVisualID(EObject domainElement) {
		if (domainElement == null) {
			return -1;
		}
		if (MuicmPackage.eINSTANCE.getMUICM().isSuperTypeOf(domainElement.eClass())
				&& isDiagram((muicm.MUICM) domainElement)) {
			return MUICMEditPart.VISUAL_ID;
		}
		return -1;
	}

	/**
	* @generated
	*/
	public static int getNodeVisualID(View containerView, EObject domainElement) {
		if (domainElement == null) {
			return -1;
		}
		String containerModelID = muicm.diagram.part.MuicmVisualIDRegistry.getModelID(containerView);
		if (!MUICMEditPart.MODEL_ID.equals(containerModelID)) {
			return -1;
		}
		int containerVisualID;
		if (MUICMEditPart.MODEL_ID.equals(containerModelID)) {
			containerVisualID = muicm.diagram.part.MuicmVisualIDRegistry.getVisualID(containerView);
		} else {
			if (containerView instanceof Diagram) {
				containerVisualID = MUICMEditPart.VISUAL_ID;
			} else {
				return -1;
			}
		}
		switch (containerVisualID) {
		case MUICMEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getScreen().isSuperTypeOf(domainElement.eClass())) {
				return ScreenEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMViewComponent().isSuperTypeOf(domainElement.eClass())) {
				return MViewComponentEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getOtherAction().isSuperTypeOf(domainElement.eClass())) {
				return OtherActionEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getCameraAction().isSuperTypeOf(domainElement.eClass())) {
				return CameraActionEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMicrophoneAction().isSuperTypeOf(domainElement.eClass())) {
				return MicrophoneActionEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getDataBindingGroup().isSuperTypeOf(domainElement.eClass())) {
				return DataBindingGroupEditPart.VISUAL_ID;
			}
			break;
		case ScreenEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getLongPressEvent().isSuperTypeOf(domainElement.eClass())) {
				return LongPressEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPanEvent().isSuperTypeOf(domainElement.eClass())) {
				return PanEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPinchEvent().isSuperTypeOf(domainElement.eClass())) {
				return PinchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getRotateEvent().isSuperTypeOf(domainElement.eClass())) {
				return RotateEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSwipeEvent().isSuperTypeOf(domainElement.eClass())) {
				return SwipeEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTapEvent().isSuperTypeOf(domainElement.eClass())) {
				return TapEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTouchEvent().isSuperTypeOf(domainElement.eClass())) {
				return TouchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMViewElementEvent().isSuperTypeOf(domainElement.eClass())) {
				return MViewElementEventEditPart.VISUAL_ID;
			}
			break;
		case MViewComponentEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getSwipeEvent().isSuperTypeOf(domainElement.eClass())) {
				return SwipeEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTapEvent().isSuperTypeOf(domainElement.eClass())) {
				return TapEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTouchEvent().isSuperTypeOf(domainElement.eClass())) {
				return TouchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPanEvent().isSuperTypeOf(domainElement.eClass())) {
				return PanEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPinchEvent().isSuperTypeOf(domainElement.eClass())) {
				return PinchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getRotateEvent().isSuperTypeOf(domainElement.eClass())) {
				return RotateEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMViewElementEvent().isSuperTypeOf(domainElement.eClass())) {
				return MViewElementEventEditPart.VISUAL_ID;
			}
			break;
		case OtherActionEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getOtherActionEvent().isSuperTypeOf(domainElement.eClass())) {
				return OtherActionEventEditPart.VISUAL_ID;
			}
			break;
		case CameraActionEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getCameraActionEvent().isSuperTypeOf(domainElement.eClass())) {
				return CameraActionEventEditPart.VISUAL_ID;
			}
			break;
		case MicrophoneActionEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getMicrophoneActionEvent().isSuperTypeOf(domainElement.eClass())) {
				return MicrophoneActionEventEditPart.VISUAL_ID;
			}
			break;
		case Screen2EditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getLongPressEvent().isSuperTypeOf(domainElement.eClass())) {
				return LongPressEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPanEvent().isSuperTypeOf(domainElement.eClass())) {
				return PanEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPinchEvent().isSuperTypeOf(domainElement.eClass())) {
				return PinchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getRotateEvent().isSuperTypeOf(domainElement.eClass())) {
				return RotateEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSwipeEvent().isSuperTypeOf(domainElement.eClass())) {
				return SwipeEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTapEvent().isSuperTypeOf(domainElement.eClass())) {
				return TapEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTouchEvent().isSuperTypeOf(domainElement.eClass())) {
				return TouchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMViewElementEvent().isSuperTypeOf(domainElement.eClass())) {
				return MViewElementEventEditPart.VISUAL_ID;
			}
			break;
		case MViewComponent2EditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getSwipeEvent().isSuperTypeOf(domainElement.eClass())) {
				return SwipeEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTapEvent().isSuperTypeOf(domainElement.eClass())) {
				return TapEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTouchEvent().isSuperTypeOf(domainElement.eClass())) {
				return TouchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPanEvent().isSuperTypeOf(domainElement.eClass())) {
				return PanEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPinchEvent().isSuperTypeOf(domainElement.eClass())) {
				return PinchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getRotateEvent().isSuperTypeOf(domainElement.eClass())) {
				return RotateEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMViewElementEvent().isSuperTypeOf(domainElement.eClass())) {
				return MViewElementEventEditPart.VISUAL_ID;
			}
			break;
		case FormEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getMViewElementEvent().isSuperTypeOf(domainElement.eClass())) {
				return MViewElementEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTouchEvent().isSuperTypeOf(domainElement.eClass())) {
				return TouchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTapEvent().isSuperTypeOf(domainElement.eClass())) {
				return TapEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSwipeEvent().isSuperTypeOf(domainElement.eClass())) {
				return SwipeEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getRotateEvent().isSuperTypeOf(domainElement.eClass())) {
				return RotateEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPinchEvent().isSuperTypeOf(domainElement.eClass())) {
				return PinchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPanEvent().isSuperTypeOf(domainElement.eClass())) {
				return PanEventEditPart.VISUAL_ID;
			}
			break;
		case ListEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getMViewElementEvent().isSuperTypeOf(domainElement.eClass())) {
				return MViewElementEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTouchEvent().isSuperTypeOf(domainElement.eClass())) {
				return TouchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTapEvent().isSuperTypeOf(domainElement.eClass())) {
				return TapEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSwipeEvent().isSuperTypeOf(domainElement.eClass())) {
				return SwipeEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getRotateEvent().isSuperTypeOf(domainElement.eClass())) {
				return RotateEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPinchEvent().isSuperTypeOf(domainElement.eClass())) {
				return PinchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPanEvent().isSuperTypeOf(domainElement.eClass())) {
				return PanEventEditPart.VISUAL_ID;
			}
			break;
		case DetailsEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getMViewElementEvent().isSuperTypeOf(domainElement.eClass())) {
				return MViewElementEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTouchEvent().isSuperTypeOf(domainElement.eClass())) {
				return TouchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTapEvent().isSuperTypeOf(domainElement.eClass())) {
				return TapEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSwipeEvent().isSuperTypeOf(domainElement.eClass())) {
				return SwipeEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getRotateEvent().isSuperTypeOf(domainElement.eClass())) {
				return RotateEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPinchEvent().isSuperTypeOf(domainElement.eClass())) {
				return PinchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPanEvent().isSuperTypeOf(domainElement.eClass())) {
				return PanEventEditPart.VISUAL_ID;
			}
			break;
		case UtilityViewEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getMViewElementEvent().isSuperTypeOf(domainElement.eClass())) {
				return MViewElementEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTouchEvent().isSuperTypeOf(domainElement.eClass())) {
				return TouchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTapEvent().isSuperTypeOf(domainElement.eClass())) {
				return TapEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSwipeEvent().isSuperTypeOf(domainElement.eClass())) {
				return SwipeEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getRotateEvent().isSuperTypeOf(domainElement.eClass())) {
				return RotateEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPinchEvent().isSuperTypeOf(domainElement.eClass())) {
				return PinchEventEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getPanEvent().isSuperTypeOf(domainElement.eClass())) {
				return PanEventEditPart.VISUAL_ID;
			}
			break;
		case SearchViewEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getTapEvent().isSuperTypeOf(domainElement.eClass())) {
				return TapEventEditPart.VISUAL_ID;
			}
			break;
		case ToolBarEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getTapEvent().isSuperTypeOf(domainElement.eClass())) {
				return TapEventEditPart.VISUAL_ID;
			}
			break;
		case ScreenScreenCompartmentEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getScreen().isSuperTypeOf(domainElement.eClass())) {
				return Screen2EditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMViewComponent().isSuperTypeOf(domainElement.eClass())) {
				return MViewComponent2EditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getForm().isSuperTypeOf(domainElement.eClass())) {
				return FormEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getList().isSuperTypeOf(domainElement.eClass())) {
				return ListEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getDetails().isSuperTypeOf(domainElement.eClass())) {
				return DetailsEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMessage().isSuperTypeOf(domainElement.eClass())) {
				return MessageEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getUtilityView().isSuperTypeOf(domainElement.eClass())) {
				return UtilityViewEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSearchView().isSuperTypeOf(domainElement.eClass())) {
				return SearchViewEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getToolBar().isSuperTypeOf(domainElement.eClass())) {
				return ToolBarEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getData().isSuperTypeOf(domainElement.eClass())) {
				return DataEditPart.VISUAL_ID;
			}
			break;
		case ScreenScreenCompartment2EditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getScreen().isSuperTypeOf(domainElement.eClass())) {
				return Screen2EditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMViewComponent().isSuperTypeOf(domainElement.eClass())) {
				return MViewComponent2EditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getForm().isSuperTypeOf(domainElement.eClass())) {
				return FormEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getList().isSuperTypeOf(domainElement.eClass())) {
				return ListEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getDetails().isSuperTypeOf(domainElement.eClass())) {
				return DetailsEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMessage().isSuperTypeOf(domainElement.eClass())) {
				return MessageEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getUtilityView().isSuperTypeOf(domainElement.eClass())) {
				return UtilityViewEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSearchView().isSuperTypeOf(domainElement.eClass())) {
				return SearchViewEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getToolBar().isSuperTypeOf(domainElement.eClass())) {
				return ToolBarEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getData().isSuperTypeOf(domainElement.eClass())) {
				return DataEditPart.VISUAL_ID;
			}
			break;
		case MViewComponentMViewComponentCompartmentEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getLabel().isSuperTypeOf(domainElement.eClass())) {
				return LabelEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTextBox().isSuperTypeOf(domainElement.eClass())) {
				return TextBoxEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMap().isSuperTypeOf(domainElement.eClass())) {
				return MapEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getCalendar().isSuperTypeOf(domainElement.eClass())) {
				return CalendarEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getCode().isSuperTypeOf(domainElement.eClass())) {
				return CodeEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSimpleField().isSuperTypeOf(domainElement.eClass())) {
				return SimpleFieldEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSelectionField().isSuperTypeOf(domainElement.eClass())) {
				return SelectionFieldEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMViewComponentPart().isSuperTypeOf(domainElement.eClass())) {
				return MViewComponentPartEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getStaticContent().isSuperTypeOf(domainElement.eClass())) {
				return StaticContentEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getDynamicBehaviour().isSuperTypeOf(domainElement.eClass())) {
				return DynamicBehaviourEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMedia().isSuperTypeOf(domainElement.eClass())) {
				return MediaEditPart.VISUAL_ID;
			}
			break;
		case FormFormCompartmentEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getData().isSuperTypeOf(domainElement.eClass())) {
				return DataEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSimpleField().isSuperTypeOf(domainElement.eClass())) {
				return SimpleField2EditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSelectionField().isSuperTypeOf(domainElement.eClass())) {
				return SelectionField2EditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getLabel().isSuperTypeOf(domainElement.eClass())) {
				return Label2EditPart.VISUAL_ID;
			}
			break;
		case ListListCompartmentEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getData().isSuperTypeOf(domainElement.eClass())) {
				return DataEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSimpleField().isSuperTypeOf(domainElement.eClass())) {
				return SimpleField2EditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getLabel().isSuperTypeOf(domainElement.eClass())) {
				return Label2EditPart.VISUAL_ID;
			}
			break;
		case DetailsDetailsCompartmentEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getTextBox().isSuperTypeOf(domainElement.eClass())) {
				return TextBox2EditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getStaticContent().isSuperTypeOf(domainElement.eClass())) {
				return StaticContent2EditPart.VISUAL_ID;
			}
			break;
		case UtilityViewUtilityViewCompartmentEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getMap().isSuperTypeOf(domainElement.eClass())) {
				return Map2EditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getCode().isSuperTypeOf(domainElement.eClass())) {
				return Code2EditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getCalendar().isSuperTypeOf(domainElement.eClass())) {
				return Calendar2EditPart.VISUAL_ID;
			}
			break;
		case SearchViewSearchViewCompartmentEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getSimpleField().isSuperTypeOf(domainElement.eClass())) {
				return SimpleField2EditPart.VISUAL_ID;
			}
			break;
		case ToolBarToolBarCompartmentEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getLabel().isSuperTypeOf(domainElement.eClass())) {
				return Label2EditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getIcon().isSuperTypeOf(domainElement.eClass())) {
				return IconEditPart.VISUAL_ID;
			}
			break;
		case MViewComponentMViewComponentCompartment2EditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getLabel().isSuperTypeOf(domainElement.eClass())) {
				return LabelEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getTextBox().isSuperTypeOf(domainElement.eClass())) {
				return TextBoxEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMap().isSuperTypeOf(domainElement.eClass())) {
				return MapEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getCalendar().isSuperTypeOf(domainElement.eClass())) {
				return CalendarEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getCode().isSuperTypeOf(domainElement.eClass())) {
				return CodeEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSimpleField().isSuperTypeOf(domainElement.eClass())) {
				return SimpleFieldEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getSelectionField().isSuperTypeOf(domainElement.eClass())) {
				return SelectionFieldEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMViewComponentPart().isSuperTypeOf(domainElement.eClass())) {
				return MViewComponentPartEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getStaticContent().isSuperTypeOf(domainElement.eClass())) {
				return StaticContentEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getDynamicBehaviour().isSuperTypeOf(domainElement.eClass())) {
				return DynamicBehaviourEditPart.VISUAL_ID;
			}
			if (MuicmPackage.eINSTANCE.getMedia().isSuperTypeOf(domainElement.eClass())) {
				return MediaEditPart.VISUAL_ID;
			}
			break;
		case DataBindingGroupDataBindingGroupCompartmentEditPart.VISUAL_ID:
			if (MuicmPackage.eINSTANCE.getDataBinding().isSuperTypeOf(domainElement.eClass())) {
				return DataBindingEditPart.VISUAL_ID;
			}
			break;
		}
		return -1;
	}

	/**
	* @generated
	*/
	public static boolean canCreateNode(View containerView, int nodeVisualID) {
		String containerModelID = muicm.diagram.part.MuicmVisualIDRegistry.getModelID(containerView);
		if (!MUICMEditPart.MODEL_ID.equals(containerModelID)) {
			return false;
		}
		int containerVisualID;
		if (MUICMEditPart.MODEL_ID.equals(containerModelID)) {
			containerVisualID = muicm.diagram.part.MuicmVisualIDRegistry.getVisualID(containerView);
		} else {
			if (containerView instanceof Diagram) {
				containerVisualID = MUICMEditPart.VISUAL_ID;
			} else {
				return false;
			}
		}
		switch (containerVisualID) {
		case MUICMEditPart.VISUAL_ID:
			if (ScreenEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewComponentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (OtherActionEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (CameraActionEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MicrophoneActionEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (DataBindingGroupEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case ScreenEditPart.VISUAL_ID:
			if (ScreenNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (ScreenScreenCompartmentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (LongPressEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PanEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PinchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (RotateEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SwipeEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TapEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TouchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewElementEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case MViewComponentEditPart.VISUAL_ID:
			if (MViewComponentNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewComponentMViewComponentCompartment2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SwipeEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TapEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TouchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PanEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PinchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (RotateEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewElementEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case OtherActionEditPart.VISUAL_ID:
			if (OtherActionNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (OtherActionEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case CameraActionEditPart.VISUAL_ID:
			if (CameraActionNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (CameraActionEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case MicrophoneActionEditPart.VISUAL_ID:
			if (MicrophoneActionNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MicrophoneActionEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case DataBindingGroupEditPart.VISUAL_ID:
			if (DataBindingGroupNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (DataBindingGroupDataBindingGroupCompartmentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case Screen2EditPart.VISUAL_ID:
			if (ScreenName2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (ScreenScreenCompartment2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (LongPressEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PanEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PinchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (RotateEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SwipeEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TapEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TouchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewElementEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case MViewComponent2EditPart.VISUAL_ID:
			if (MViewComponentName2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewComponentMViewComponentCompartmentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SwipeEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TapEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TouchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PanEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PinchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (RotateEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewElementEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case LabelEditPart.VISUAL_ID:
			if (LabelNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case TextBoxEditPart.VISUAL_ID:
			if (TextBoxNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case MapEditPart.VISUAL_ID:
			if (MapNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case CalendarEditPart.VISUAL_ID:
			if (CalendarNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case CodeEditPart.VISUAL_ID:
			if (CodeNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case SimpleFieldEditPart.VISUAL_ID:
			if (SimpleFieldNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case SelectionFieldEditPart.VISUAL_ID:
			if (SelectionFieldNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case SwipeEventEditPart.VISUAL_ID:
			if (SwipeEventNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case TapEventEditPart.VISUAL_ID:
			if (TapEventNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case TouchEventEditPart.VISUAL_ID:
			if (TouchEventNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case PanEventEditPart.VISUAL_ID:
			if (PanEventNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case PinchEventEditPart.VISUAL_ID:
			if (PinchEventNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case RotateEventEditPart.VISUAL_ID:
			if (RotateEventNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case MViewElementEventEditPart.VISUAL_ID:
			if (MViewElementEventNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case MViewComponentPartEditPart.VISUAL_ID:
			if (MViewComponentPartNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case StaticContentEditPart.VISUAL_ID:
			if (StaticContentNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case DynamicBehaviourEditPart.VISUAL_ID:
			if (DynamicBehaviourNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case MediaEditPart.VISUAL_ID:
			if (MediaNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case FormEditPart.VISUAL_ID:
			if (FormNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (FormFormCompartmentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewElementEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TouchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TapEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SwipeEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (RotateEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PinchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PanEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case DataEditPart.VISUAL_ID:
			if (DataNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case SimpleField2EditPart.VISUAL_ID:
			if (SimpleFieldName2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case SelectionField2EditPart.VISUAL_ID:
			if (SelectionFieldName2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case Label2EditPart.VISUAL_ID:
			if (LabelName2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case ListEditPart.VISUAL_ID:
			if (ListNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (ListListCompartmentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewElementEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TouchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TapEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SwipeEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (RotateEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PinchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PanEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case DetailsEditPart.VISUAL_ID:
			if (DetailsNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (DetailsDetailsCompartmentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewElementEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TouchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TapEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SwipeEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (RotateEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PinchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PanEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case TextBox2EditPart.VISUAL_ID:
			if (TextBoxName2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case StaticContent2EditPart.VISUAL_ID:
			if (StaticContentName2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case MessageEditPart.VISUAL_ID:
			if (MessageNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case UtilityViewEditPart.VISUAL_ID:
			if (UtilityViewNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (UtilityViewUtilityViewCompartmentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewElementEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TouchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TapEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SwipeEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (RotateEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PinchEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (PanEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case Map2EditPart.VISUAL_ID:
			if (MapName2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case Code2EditPart.VISUAL_ID:
			if (CodeName2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case Calendar2EditPart.VISUAL_ID:
			if (CalendarName2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case SearchViewEditPart.VISUAL_ID:
			if (SearchViewNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SearchViewSearchViewCompartmentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TapEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case ToolBarEditPart.VISUAL_ID:
			if (ToolBarNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (ToolBarToolBarCompartmentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TapEventEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case IconEditPart.VISUAL_ID:
			if (IconNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case LongPressEventEditPart.VISUAL_ID:
			if (LongPressEventNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case OtherActionEventEditPart.VISUAL_ID:
			if (OtherActionEventNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case CameraActionEventEditPart.VISUAL_ID:
			if (CameraActionEventNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case MicrophoneActionEventEditPart.VISUAL_ID:
			if (MicrophoneActionEventNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case DataBindingEditPart.VISUAL_ID:
			if (DataBindingSourceDataEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (DataBindingTargetDataEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case ScreenScreenCompartmentEditPart.VISUAL_ID:
			if (Screen2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewComponent2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (FormEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (ListEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (DetailsEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MessageEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (UtilityViewEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SearchViewEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (ToolBarEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (DataEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case ScreenScreenCompartment2EditPart.VISUAL_ID:
			if (Screen2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewComponent2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (FormEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (ListEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (DetailsEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MessageEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (UtilityViewEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SearchViewEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (ToolBarEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (DataEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case MViewComponentMViewComponentCompartmentEditPart.VISUAL_ID:
			if (LabelEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TextBoxEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MapEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (CalendarEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (CodeEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SimpleFieldEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SelectionFieldEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewComponentPartEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (StaticContentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (DynamicBehaviourEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MediaEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case FormFormCompartmentEditPart.VISUAL_ID:
			if (DataEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SimpleField2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SelectionField2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (Label2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case ListListCompartmentEditPart.VISUAL_ID:
			if (DataEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SimpleField2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (Label2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case DetailsDetailsCompartmentEditPart.VISUAL_ID:
			if (TextBox2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (StaticContent2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case UtilityViewUtilityViewCompartmentEditPart.VISUAL_ID:
			if (Map2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (Code2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (Calendar2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case SearchViewSearchViewCompartmentEditPart.VISUAL_ID:
			if (SimpleField2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case ToolBarToolBarCompartmentEditPart.VISUAL_ID:
			if (Label2EditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (IconEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case MViewComponentMViewComponentCompartment2EditPart.VISUAL_ID:
			if (LabelEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (TextBoxEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MapEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (CalendarEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (CodeEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SimpleFieldEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (SelectionFieldEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MViewComponentPartEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (StaticContentEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (DynamicBehaviourEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			if (MediaEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case DataBindingGroupDataBindingGroupCompartmentEditPart.VISUAL_ID:
			if (DataBindingEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case NavigationFlowEditPart.VISUAL_ID:
			if (NavigationFlowNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		case DataFlowEditPart.VISUAL_ID:
			if (DataFlowNameEditPart.VISUAL_ID == nodeVisualID) {
				return true;
			}
			break;
		}
		return false;
	}

	/**
	* @generated
	*/
	public static int getLinkWithClassVisualID(EObject domainElement) {
		if (domainElement == null) {
			return -1;
		}
		if (MuicmPackage.eINSTANCE.getNavigationFlow().isSuperTypeOf(domainElement.eClass())) {
			return NavigationFlowEditPart.VISUAL_ID;
		}
		if (MuicmPackage.eINSTANCE.getDataFlow().isSuperTypeOf(domainElement.eClass())) {
			return DataFlowEditPart.VISUAL_ID;
		}
		return -1;
	}

	/**
	* User can change implementation of this method to handle some specific
	* situations not covered by default logic.
	* 
	* @generated
	*/
	private static boolean isDiagram(muicm.MUICM element) {
		return true;
	}

	/**
	* @generated
	*/
	public static boolean checkNodeVisualID(View containerView, EObject domainElement, int candidate) {
		if (candidate == -1) {
			//unrecognized id is always bad
			return false;
		}
		int basic = getNodeVisualID(containerView, domainElement);
		return basic == candidate;
	}

	/**
	* @generated
	*/
	public static boolean isCompartmentVisualID(int visualID) {
		switch (visualID) {
		case ScreenScreenCompartmentEditPart.VISUAL_ID:
		case ScreenScreenCompartment2EditPart.VISUAL_ID:
		case MViewComponentMViewComponentCompartmentEditPart.VISUAL_ID:
		case FormFormCompartmentEditPart.VISUAL_ID:
		case ListListCompartmentEditPart.VISUAL_ID:
		case DetailsDetailsCompartmentEditPart.VISUAL_ID:
		case UtilityViewUtilityViewCompartmentEditPart.VISUAL_ID:
		case SearchViewSearchViewCompartmentEditPart.VISUAL_ID:
		case ToolBarToolBarCompartmentEditPart.VISUAL_ID:
		case MViewComponentMViewComponentCompartment2EditPart.VISUAL_ID:
		case DataBindingGroupDataBindingGroupCompartmentEditPart.VISUAL_ID:
			return true;
		default:
			break;
		}
		return false;
	}

	/**
	* @generated
	*/
	public static boolean isSemanticLeafVisualID(int visualID) {
		switch (visualID) {
		case MUICMEditPart.VISUAL_ID:
			return false;
		case MessageEditPart.VISUAL_ID:
		case LongPressEventEditPart.VISUAL_ID:
		case PanEventEditPart.VISUAL_ID:
		case PinchEventEditPart.VISUAL_ID:
		case RotateEventEditPart.VISUAL_ID:
		case SwipeEventEditPart.VISUAL_ID:
		case TapEventEditPart.VISUAL_ID:
		case TouchEventEditPart.VISUAL_ID:
		case OtherActionEventEditPart.VISUAL_ID:
		case CameraActionEventEditPart.VISUAL_ID:
		case MicrophoneActionEventEditPart.VISUAL_ID:
		case DataBindingEditPart.VISUAL_ID:
		case LabelEditPart.VISUAL_ID:
		case TextBoxEditPart.VISUAL_ID:
		case MapEditPart.VISUAL_ID:
		case CalendarEditPart.VISUAL_ID:
		case CodeEditPart.VISUAL_ID:
		case SimpleFieldEditPart.VISUAL_ID:
		case SelectionFieldEditPart.VISUAL_ID:
		case MViewElementEventEditPart.VISUAL_ID:
		case MViewComponentPartEditPart.VISUAL_ID:
		case StaticContentEditPart.VISUAL_ID:
		case DynamicBehaviourEditPart.VISUAL_ID:
		case DataEditPart.VISUAL_ID:
		case SimpleField2EditPart.VISUAL_ID:
		case SelectionField2EditPart.VISUAL_ID:
		case Label2EditPart.VISUAL_ID:
		case TextBox2EditPart.VISUAL_ID:
		case StaticContent2EditPart.VISUAL_ID:
		case Map2EditPart.VISUAL_ID:
		case Code2EditPart.VISUAL_ID:
		case Calendar2EditPart.VISUAL_ID:
		case IconEditPart.VISUAL_ID:
		case MediaEditPart.VISUAL_ID:
			return true;
		default:
			break;
		}
		return false;
	}

	/**
	* @generated
	*/
	public static final DiagramStructure TYPED_INSTANCE = new DiagramStructure() {
		/**
		* @generated
		*/
		@Override

		public int getVisualID(View view) {
			return muicm.diagram.part.MuicmVisualIDRegistry.getVisualID(view);
		}

		/**
		* @generated
		*/
		@Override

		public String getModelID(View view) {
			return muicm.diagram.part.MuicmVisualIDRegistry.getModelID(view);
		}

		/**
		* @generated
		*/
		@Override

		public int getNodeVisualID(View containerView, EObject domainElement) {
			return muicm.diagram.part.MuicmVisualIDRegistry.getNodeVisualID(containerView, domainElement);
		}

		/**
		* @generated
		*/
		@Override

		public boolean checkNodeVisualID(View containerView, EObject domainElement, int candidate) {
			return muicm.diagram.part.MuicmVisualIDRegistry.checkNodeVisualID(containerView, domainElement, candidate);
		}

		/**
		* @generated
		*/
		@Override

		public boolean isCompartmentVisualID(int visualID) {
			return muicm.diagram.part.MuicmVisualIDRegistry.isCompartmentVisualID(visualID);
		}

		/**
		* @generated
		*/
		@Override

		public boolean isSemanticLeafVisualID(int visualID) {
			return muicm.diagram.part.MuicmVisualIDRegistry.isSemanticLeafVisualID(visualID);
		}
	};

}
